#!/usr/bin/env python
# -*- coding: utf-8 -*-
#

# Code generated by:
# python -m pwiz -e postgresql sdss5db -s vizdb -i -o -H localhost -p 6000 -u u0857802
# Date: October 18, 2023 03:26PM
# Database: sdss5db
# Peewee version: 3.13.2

from peewee import (AutoField, BigIntegerField, BooleanField, CharField, DateField, DecimalField,
                    DoubleField, FloatField, IntegerField,
                    SmallIntegerField, TextField, DateTimeField)
from playhouse.postgres_ext import ArrayField
from datetime import datetime

from .. import BaseModel
from . import database  # noqa


class VizBase(BaseModel):

    class Meta:
        schema = 'vizdb'
        database = database


class SDSSidFlat(VizBase):

    sdss_id = BigIntegerField(null=False)
    catalogid = BigIntegerField(null=True)
    version_id = SmallIntegerField(null=True)
    ra_sdss_id = DoubleField(null=True)
    dec_sdss_id = DoubleField(null=True)
    n_associated = SmallIntegerField(null=True)
    pk = AutoField()
    ra_catalogid = DoubleField(null=True)
    dec_catalogid = DoubleField(null=True)
    rank = IntegerField(null=True)

    class Meta:
        table_name = 'sdss_id_flat'
        print_fields = ['sdss_id', 'catalogid', 'version_id', 'ra_sdss_id', 'dec_sdss_id']


class SDSSidStacked(VizBase):

    catalogid21 = BigIntegerField(null=True)
    catalogid25 = BigIntegerField(null=True)
    catalogid31 = BigIntegerField(null=True)
    ra_sdss_id = DoubleField(null=True)
    dec_sdss_id = DoubleField(null=True)
    sdss_id = BigIntegerField(null=False, primary_key=True)
    last_updated = DateField(null=True)

    class Meta:
        table_name = 'sdss_id_stacked'
        print_fields = ['sdss_id', 'ra_sdss_id', 'dec_sdss_id']


class SDSSidToPipes(VizBase):

    pk = AutoField(primary_key=True)
    sdss_id = BigIntegerField(null=False)
    in_boss = BooleanField(null=False)
    in_apogee = BooleanField(null=False)
    in_bvs = BooleanField(null=False)
    in_astra = BooleanField(null=False)
    has_been_observed = BooleanField(null=False)
    release = TextField(null=True)
    obs = TextField(null=True)
    mjd = IntegerField(null=True)

    class Meta:
        table_name = 'sdssid_to_pipes'
        print_fields = ['sdss_id', 'in_boss', 'in_apogee', 'in_astra', 'has_been_observed']


class DbMetadata(VizBase):
    pk = AutoField()
    schema = TextField(null=True)
    table_name = TextField(null=True)
    column_name = TextField(null=True)
    display_name = TextField(null=True)
    description = TextField(null=True)
    unit = TextField(null=True)
    sql_type = TextField(null=True)

    class Meta:
        table_name = 'db_metadata'
        print_fields = ['schema', 'table_name', 'column_name', 'display_name']


class Releases(VizBase):

    pk = AutoField()
    release = TextField(null=True)
    run2d = ArrayField(TextField, null=True)
    run1d = ArrayField(TextField, null=True)
    apred_vers = ArrayField(TextField, null=True)
    v_astra = TextField(null=True)
    v_speccomp = TextField(null=True)
    v_targ = TextField(null=True)
    drpver = TextField(null=True)
    dapver = TextField(null=True)
    apstar_vers = TextField(null=True)
    aspcap_vers = TextField(null=True)
    results_vers = TextField(null=True)
    public = BooleanField(null=False)
    mjd_cutoff_apo = IntegerField(null=False)
    mjd_cutoff_lco = IntegerField(null=False)

    class Meta:
        table_name = 'releases'
        print_fields = ['release']

class Multiplex(VizBase):

    pk = AutoField()
    multiplex_id = TextField()
    releases_pk = IntegerField(null=True)
    design_id = IntegerField()
    sdss_phase = SmallIntegerField(null=True)
    observatory = TextField(null=True)
    instrument = TextField(null=True)
    plate = IntegerField(null=True)
    fps_field = IntegerField(null=True)
    plate_or_fps_field = IntegerField(null=True)
    mjd = IntegerField(null=True)
    run2d = TextField(null=True)
    apred_vers = TextField(null=True)
    drpver = TextField(null=True)
    version = TextField(null=True)
    racen = DoubleField(null=True)
    deccen = DoubleField(null=True)
    position_angle = DoubleField(null=True)
    racen_hms = TextField(null=True)
    deccen_dms = TextField(null=True)
    healpix = IntegerField(null=True)
    healpixgrp = SmallIntegerField(null=True)
    quality = TextField(null=True)
    programname = TextField(null=True)
    survey = TextField(null=True)
    cas_url = TextField(null=True)
    sas_url = TextField(null=True)
    created = DateTimeField(default=datetime.now)
    modified = DateTimeField()


    class Meta:
        table_name = 'multiplex'
        print_fields = ['multiplex_id']



class AllSpec(VizBase):

    pk = AutoField()
    allspec_id = TextField()
    multiplex_id = TextField()
    releases_pk = IntegerField()
    sdss_phase = SmallIntegerField(null=True)
    observatory = TextField(null=True)
    instrument = TextField(null=True)
    sdss_id = BigIntegerField()
    catalogid = BigIntegerField()
    fiberid = IntegerField(null=True)
    ifudsgn = SmallIntegerField()
    plate = IntegerField(null=True)
    fps_field = IntegerField(null=True)
    plate_or_fps_field = IntegerField(null=True)
    mjd = IntegerField(null=True)
    run2d = TextField(null=True)
    run1d = TextField(null=True)
    coadd = TextField(null=True)
    apred_vers = TextField(null=True)
    drpver = TextField(null=True)
    version = TextField(null=True)
    programname = TextField(null=True)
    survey = TextField(null=True)
    sas_file = TextField(null=True)
    cas_url = TextField(null=True)
    sas_url = TextField(null=True)
    ra = DoubleField(null=True)
    dec = DoubleField(null=True)
    ra_hms = TextField(null=True)
    dec_dms = TextField(null=True)
    healpix = IntegerField(null=True)
    healpixgrp = SmallIntegerField(null=True)
    apogee_id = TextField(null=True)
    apogee_field = TextField(null=True)
    telescope = TextField(null=True)
    file_spec = TextField(null=True)
    apstar_id = TextField(null=True)
    visit_id = TextField(null=True)
    mangaid = TextField(null=True)
    specobjid = DecimalField(29)
    created = DateTimeField(default=datetime.now)
    modified = DateTimeField()


    class Meta:
        table_name = 'allspec'
        print_fields = ['allspec_id']



class Plate(VizBase):
    plate_id = AutoField()
    tree_id = SmallIntegerField()
    first_release = CharField(max_length=32)
    plate = SmallIntegerField()
    mjd = IntegerField()
    mjd_list = CharField(max_length=512)
    survey = CharField(max_length=32)
    programname = CharField(max_length=32)
    instrument = CharField(max_length=32)
    chunk = CharField(max_length=32)
    plate_run = CharField(max_length=32)
    design_comments = CharField(max_length=128)
    quality = CharField(max_length=32)
    quality_comments = CharField(max_length=100)
    plate_sn2 = FloatField()
    dered_sn2 = FloatField()
    racen = DoubleField()
    deccen = DoubleField()
    racen_hms = CharField(max_length=12)
    deccen_dms = CharField(max_length=12)
    run2d = CharField(max_length=32)
    run1d = CharField(max_length=32)
    runsspp = CharField(max_length=32)
    tile = SmallIntegerField()
    design_id = IntegerField()
    location_id = IntegerField()
    iop_version = CharField(max_length=64)
    cam_version = CharField(max_length=64)
    tai_hms = CharField(max_length=64)
    date_obs = CharField(max_length=24)
    time_sys = CharField(max_length=8)
    cx = DoubleField()
    cy = DoubleField()
    cz = DoubleField()
    cartridge_id = SmallIntegerField()
    tai = DoubleField()
    tai_begin = DoubleField()
    tai_end = DoubleField()
    airmass = FloatField()
    map_mjd = IntegerField()
    map_name = CharField(max_length=32)
    plug_file = CharField(max_length=32)
    exp_time = FloatField()
    exp_time_b1 = FloatField()
    exp_time_b2 = FloatField()
    exp_time_r1 = FloatField()
    exp_time_r2 = FloatField()
    vers2d = CharField(max_length=32)
    verscomb = CharField(max_length=32)
    vers1d = CharField(max_length=32)
    snturnoff = FloatField()
    nturnoff = FloatField()
    n_exp = SmallIntegerField()
    n_exp_b1 = SmallIntegerField()
    n_exp_b2 = SmallIntegerField()
    n_exp_r1 = SmallIntegerField()
    n_exp_r2 = SmallIntegerField()
    sn1_g = FloatField()
    sn1_r = FloatField()
    sn1_i = FloatField()
    sn2_g = FloatField()
    sn2_r = FloatField()
    sn2_i = FloatField()
    dered_sn1_g = FloatField()
    dered_sn1_r = FloatField()
    dered_sn1_i = FloatField()
    dered_sn2_g = FloatField()
    dered_sn2_r = FloatField()
    dered_sn2_i = FloatField()
    helio_rv = FloatField()
    g_off_std = FloatField()
    g_rms_std = FloatField()
    r_off_std = FloatField()
    r_rms_std = FloatField()
    i_off_std = FloatField()
    i_rms_std = FloatField()
    gr_off_std = FloatField()
    gr_rms_std = FloatField()
    ri_off_std = FloatField()
    ri_rms_std = FloatField()
    g_off_gal = FloatField()
    g_rms_gal = FloatField()
    r_off_gal = FloatField()
    r_rms_gal = FloatField()
    i_off_gal = FloatField()
    i_rms_gal = FloatField()
    gr_off_gal = FloatField()
    gr_rms_gal = FloatField()
    ri_off_gal = FloatField()
    ri_rms_gal = FloatField()
    n_guide = IntegerField()
    seeing20 = FloatField()
    seeing50 = FloatField()
    seeing80 = FloatField()
    rmsoff20 = FloatField()
    rmsoff50 = FloatField()
    rmsoff80 = FloatField()
    airtemp = FloatField()
    sfd_used = SmallIntegerField()
    x_sigma = FloatField()
    x_sig_min = FloatField()
    x_sig_max = FloatField()
    w_sigma = FloatField()
    w_sig_min = FloatField()
    w_sig_max = FloatField()
    x_chi2 = FloatField()
    x_chi2_min = FloatField()
    x_chi2_max = FloatField()
    sky_chi2 = FloatField()
    sky_chi2_min = FloatField()
    sky_chi2_max = FloatField()
    f_bad_pix = FloatField()
    f_bad_pix1 = FloatField()
    f_bad_pix2 = FloatField()
    status2d = CharField(max_length=32)
    statuscombine = CharField(max_length=32)
    status1d = CharField(max_length=32)
    n_total = IntegerField()
    n_galaxy = IntegerField()
    n_qso = IntegerField()
    n_star = IntegerField()
    n_sky = IntegerField()
    n_unknown = IntegerField()
    is_best = SmallIntegerField()
    is_primary = SmallIntegerField()
    is_tile = SmallIntegerField()
    ha = FloatField()
    mjd_design = IntegerField()
    theta = FloatField()
    fscan_version = CharField(max_length=32)
    fmap_version = CharField(max_length=32)
    fscan_mode = CharField(max_length=32)
    fscan_speed = IntegerField()
    htm_id = BigIntegerField()
    load_version = IntegerField()

    class Meta:
        table_name = 'plate'
        print_fields = ['plate_id', 'tree_id', 'plate', 'mjd', 'survey', 'instrument']



class SpecObj(VizBase):
    specobj_id = AutoField()
    tree_id = SmallIntegerField()
    bestobj_id = BigIntegerField()
    fluxobj_id = BigIntegerField()
    targetobj_id = BigIntegerField()
    plate_id = DecimalField(20)
    science_primary = SmallIntegerField()
    sdss_primary = SmallIntegerField()
    legacy_primary = SmallIntegerField()
    segue_primary = SmallIntegerField()
    segue1_primary = SmallIntegerField()
    segue2_primary = SmallIntegerField()
    boss_primary = SmallIntegerField()
    boss_specobj_id = IntegerField()
    first_release = CharField(max_length=32)
    survey = CharField(max_length=32)
    instrument = CharField(max_length=32)
    programname = CharField(max_length=32)
    chunk = CharField(max_length=32)
    plate_run = CharField(max_length=32)
    mjd = IntegerField()
    plate = SmallIntegerField()
    fiberid = SmallIntegerField()
    run1d = CharField(max_length=32)
    run2d = CharField(max_length=32)
    tile = IntegerField()
    design_id = IntegerField()
    legacy_target1 = BigIntegerField()
    legacy_target2 = BigIntegerField()
    special_target1 = BigIntegerField()
    special_target2 = BigIntegerField()
    segue1_target1 = BigIntegerField()
    segue1_target2 = BigIntegerField()
    segue2_target1 = BigIntegerField()
    segue2_target2 = BigIntegerField()
    boss_target1 = BigIntegerField()
    eboss_target0 = BigIntegerField()
    eboss_target1 = BigIntegerField()
    eboss_target2 = BigIntegerField()
    sdssv_boss_target0 = BigIntegerField()
    eboss_target_id = BigIntegerField()
    ancillary_target1 = BigIntegerField()
    ancillary_target2 = BigIntegerField()
    thing_id_targeting = BigIntegerField()
    thing_id = BigIntegerField()
    prim_target = BigIntegerField()
    sec_target = BigIntegerField()
    spectrograph_id = SmallIntegerField()
    source_type = CharField(max_length=128)
    target_type = CharField(max_length=128)
    ra = DoubleField()
    dec = DoubleField()
    ra_hms = CharField(max_length=12)
    dec_dms = CharField(max_length=12)
    cx = DoubleField()
    cy = DoubleField()
    cz = DoubleField()
    x_focal = FloatField()
    y_focal = FloatField()
    lambda_eff = FloatField()
    blue_fiber = IntegerField()
    zoffset = FloatField()
    z = FloatField()
    zerr = FloatField()
    zwarning = IntegerField()
    objclass = CharField(max_length=32)
    subclass = CharField(max_length=32)
    r_chi2 = FloatField()
    dof = FloatField()
    r_chi2_diff = FloatField()
    z_noqso = FloatField()
    zerr_noqso = FloatField()
    zwarning_noqso = IntegerField()
    class_noqso = CharField(max_length=32)
    subclass_noqso = CharField(max_length=32)
    r_chi2_diff_noqso = FloatField()
    z_person = FloatField()
    class_person = CharField(max_length=32)
    comments_person = CharField(max_length=200)
    tfile = CharField(max_length=32)
    tcolumn_0 = SmallIntegerField()
    tcolumn_1 = SmallIntegerField()
    tcolumn_2 = SmallIntegerField()
    tcolumn_3 = SmallIntegerField()
    tcolumn_4 = SmallIntegerField()
    tcolumn_5 = SmallIntegerField()
    tcolumn_6 = SmallIntegerField()
    tcolumn_7 = SmallIntegerField()
    tcolumn_8 = SmallIntegerField()
    tcolumn_9 = SmallIntegerField()
    npoly = FloatField()
    theta_0 = FloatField()
    theta_1 = FloatField()
    theta_2 = FloatField()
    theta_3 = FloatField()
    theta_4 = FloatField()
    theta_5 = FloatField()
    theta_6 = FloatField()
    theta_7 = FloatField()
    theta_8 = FloatField()
    theta_9 = FloatField()
    vel_disp = FloatField()
    vel_disp_err = FloatField()
    vel_disp_z = FloatField()
    vel_disp_zerr = FloatField()
    vel_disp_chi2 = FloatField()
    vel_disp_npix = IntegerField()
    vel_disp_dof = IntegerField()
    wave_min = FloatField()
    wave_max = FloatField()
    wcoverage = FloatField()
    sn_median_u = FloatField()
    sn_median_g = FloatField()
    sn_median_r = FloatField()
    sn_median_i = FloatField()
    sn_median_z = FloatField()
    sn_median = FloatField()
    chi68p = FloatField()
    frac_n_sigma_1 = FloatField()
    frac_n_sigma_2 = FloatField()
    frac_n_sigma_3 = FloatField()
    frac_n_sigma_4 = FloatField()
    frac_n_sigma_5 = FloatField()
    frac_n_sigma_6 = FloatField()
    frac_n_sigma_7 = FloatField()
    frac_n_sigma_8 = FloatField()
    frac_n_sigma_9 = FloatField()
    frac_n_sigma_10 = FloatField()
    frac_n_sig_hi_1 = FloatField()
    frac_n_sig_hi_2 = FloatField()
    frac_n_sig_hi_3 = FloatField()
    frac_n_sig_hi_4 = FloatField()
    frac_n_sig_hi_5 = FloatField()
    frac_n_sig_hi_6 = FloatField()
    frac_n_sig_hi_7 = FloatField()
    frac_n_sig_hi_8 = FloatField()
    frac_n_sig_hi_9 = FloatField()
    frac_n_sig_hi_10 = FloatField()
    frac_n_sig_lo_1 = FloatField()
    frac_n_sig_lo_2 = FloatField()
    frac_n_sig_lo_3 = FloatField()
    frac_n_sig_lo_4 = FloatField()
    frac_n_sig_lo_5 = FloatField()
    frac_n_sig_lo_6 = FloatField()
    frac_n_sig_lo_7 = FloatField()
    frac_n_sig_lo_8 = FloatField()
    frac_n_sig_lo_9 = FloatField()
    frac_n_sig_lo_10 = FloatField()
    spectro_flux_u = FloatField()
    spectro_flux_g = FloatField()
    spectro_flux_r = FloatField()
    spectro_flux_i = FloatField()
    spectro_flux_z = FloatField()
    spectro_syn_flux_u = FloatField()
    spectro_syn_flux_g = FloatField()
    spectro_syn_flux_r = FloatField()
    spectro_syn_flux_i = FloatField()
    spectro_syn_flux_z = FloatField()
    spectro_flux_ivar_u = FloatField()
    spectro_flux_ivar_g = FloatField()
    spectro_flux_ivar_r = FloatField()
    spectro_flux_ivar_i = FloatField()
    spectro_flux_ivar_z = FloatField()
    spectro_syn_flux_ivar_u = FloatField()
    spectro_syn_flux_ivar_g = FloatField()
    spectro_syn_flux_ivar_r = FloatField()
    spectro_syn_flux_ivar_i = FloatField()
    spectro_syn_flux_ivar_z = FloatField()
    spectro_sky_flux_u = FloatField()
    spectro_sky_flux_g = FloatField()
    spectro_sky_flux_r = FloatField()
    spectro_sky_flux_i = FloatField()
    spectro_sky_flux_z = FloatField()
    any_and_mask = IntegerField()
    any_or_mask = IntegerField()
    plate_sn2 = FloatField()
    dered_sn2 = FloatField()
    sn_turnoff = FloatField()
    sn1_g = FloatField()
    sn1_r = FloatField()
    sn1_i = FloatField()
    sn2_g = FloatField()
    sn2_r = FloatField()
    sn2_i = FloatField()
    elodie_filename = CharField(max_length=32)
    elodie_object = CharField(max_length=32)
    elodie_sp_type = CharField(max_length=32)
    elodie_bv = FloatField()
    elodie_t_eff = FloatField()
    elodie_logg = FloatField()
    elodie_fe_h = FloatField()
    elodie_z = FloatField()
    elodie_zerr = FloatField()
    elodie_zmodelerr = FloatField()
    elodie_r_chi2 = FloatField()
    elodie_dof = FloatField()
    htm_id = BigIntegerField()
    load_version = IntegerField()
    specprimary = SmallIntegerField()
    field = SmallIntegerField()
    catalogid = BigIntegerField()

    class Meta:
        table_name = 'specobj'
        print_fields = ['specobj_id', 'tree_id']
        #print_fields = ['specobj_id', 'tree_id', 'plate', 'fiberid', 'mjd', 'field', 'catalogid']
